`CGAL <http://www.cgal.org>`_ is a huge computational geometry library written in C++.
This package lets you use it with Python.

The official `wiki <https://github.com/CGAL/cgal-swig-bindings/wiki>`_ has much more information about usage and `which CGAL packages are supported <https://github.com/CGAL/cgal-swig-bindings/wiki/Package_wrappers_available>`_ in the Python bindings.

The fastest way to get started is to take a look at all the `Python examples <https://github.com/CGAL/cgal-swig-bindings/tree/master/examples/python>`_ that come with the source code. These are also used to test if you installed everything correctly.

